
country_name_en_map = {
    "AF": "Afghanistan",
    "AFG": "Afghanistan",
    "AX": "Aland Islands",
    "ALA": "Aland Islands",
    "AL": "Albania",
    "ALB": "Albania",
    "DZ": "Algeria",
    "DZA": "Algeria",
    "AS": "American Samoa",
    "ASM": "American Samoa",
    "AD": "Andorra",
    "AND": "Andorra",
    "AO": "Angola",
    "AGO": "Angola",
    "AI": "Anguilla",
    "AIA": "Anguilla",
    "AQ": "Antarctica",
    "ATA": "Antarctica",
    "AG": "Antigua and Barbuda",
    "ATG": "Antigua and Barbuda",
    "AR": "Argentina",
    "ARG": "Argentina",
    "AM": "Armenia",
    "ARM": "Armenia",
    "AW": "Aruba",
    "ABW": "Aruba",
    "AU": "Australia",
    "AUS": "Australia",
    "AT": "Austria",
    "AUT": "Austria",
    "AZ": "Azerbaijan",
    "AZE": "Azerbaijan",
    "BS": "Bahamas",
    "BHS": "Bahamas",
    "BH": "Bahrain",
    "BHR": "Bahrain",
    "BD": "Bangladesh",
    "BGD": "Bangladesh",
    "BB": "Barbados",
    "BRB": "Barbados",
    "BY": "Belarus",
    "BLR": "Belarus",
    "BE": "Belgium",
    "BEL": "Belgium",
    "BZ": "Belize",
    "BLZ": "Belize",
    "BJ": "Benin",
    "BEN": "Benin",
    "BM": "Bermuda",
    "BMU": "Bermuda",
    "BT": "Bhutan",
    "BTN": "Bhutan",
    "BO": "Bolivia (Plurinational State of)",
    "BOL": "Bolivia (Plurinational State of)",
    "BQ": "Bonaire, Sint Eustatius and Saba",
    "BES": "Bonaire, Sint Eustatius and Saba",
    "BA": "Bosnia and Herzegovina",
    "BIH": "Bosnia and Herzegovina",
    "BW": "Botswana",
    "BWA": "Botswana",
    "BV": "Bouvet Island",
    "BVT": "Bouvet Island",
    "BR": "Brazil",
    "BRA": "Brazil",
    "IO": "British Indian Ocean Territory",
    "IOT": "British Indian Ocean Territory",
    "BN": "Brunei Darussalam",
    "BRN": "Brunei Darussalam",
    "BG": "Bulgaria",
    "BGR": "Bulgaria",
    "BF": "Burkina Faso",
    "BFA": "Burkina Faso",
    "BI": "Burundi",
    "BDI": "Burundi",
    "CV": "Cabo Verde",
    "CPV": "Cabo Verde",
    "KH": "Cambodia",
    "KHM": "Cambodia",
    "CM": "Cameroon",
    "CMR": "Cameroon",
    "CA": "Canada",
    "CAN": "Canada",
    "KY": "Cayman Islands",
    "CYM": "Cayman Islands",
    "CF": "Central African Republic",
    "CAF": "Central African Republic",
    "TD": "Chad",
    "TCD": "Chad",
    "CL": "Chile",
    "CHL": "Chile",
    "CN": "China",
    "CHN": "China",
    "CX": "Christmas Island",
    "CXR": "Christmas Island",
    "CC": "Cocos (Keeling) Islands",
    "CCK": "Cocos (Keeling) Islands",
    "CO": "Colombia",
    "COL": "Colombia",
    "KM": "Comoros",
    "COM": "Comoros",
    "CG": "Congo",
    "COG": "Congo",
    "CD": "Congo (Democratic Republic of the)",
    "COD": "Congo (Democratic Republic of the)",
    "CK": "Cook Islands",
    "COK": "Cook Islands",
    "CR": "Costa Rica",
    "CRI": "Costa Rica",
    "CI": "Côte d'Ivoire",
    "CIV": "Côte d'Ivoire",
    "HR": "Croatia",
    "HRV": "Croatia",
    "CU": "Cuba",
    "CUB": "Cuba",
    "CW": "Curaçao",
    "CUW": "Curaçao",
    "CY": "Cyprus",
    "CYP": "Cyprus",
    "CZ": "Czechia",
    "CZE": "Czechia",
    "DK": "Denmark",
    "DNK": "Denmark",
    "DJ": "Djibouti",
    "DJI": "Djibouti",
    "DM": "Dominica",
    "DMA": "Dominica",
    "DO": "Dominican Republic",
    "DOM": "Dominican Republic",
    "EC": "Ecuador",
    "ECU": "Ecuador",
    "EG": "Egypt",
    "EGY": "Egypt",
    "SV": "El Salvador",
    "SLV": "El Salvador",
    "GQ": "Equatorial Guinea",
    "GNQ": "Equatorial Guinea",
    "ER": "Eritrea",
    "ERI": "Eritrea",
    "EE": "Estonia",
    "EST": "Estonia",
    "ET": "Ethiopia",
    "ETH": "Ethiopia",
    "FK": "Falkland Islands (Malvinas)",
    "FLK": "Falkland Islands (Malvinas)",
    "FO": "Faroe Islands",
    "FRO": "Faroe Islands",
    "FJ": "Fiji",
    "FJI": "Fiji",
    "FI": "Finland",
    "FIN": "Finland",
    "FR": "France",
    "FRA": "France",
    "GF": "French Guiana",
    "GUF": "French Guiana",
    "PF": "French Polynesia",
    "PYF": "French Polynesia",
    "TF": "French Southern Territories",
    "ATF": "French Southern Territories",
    "GA": "Gabon",
    "GAB": "Gabon",
    "GM": "Gambia",
    "GMB": "Gambia",
    "GE": "Georgia",
    "GEO": "Georgia",
    "DE": "Germany",
    "DEU": "Germany",
    "GH": "Ghana",
    "GHA": "Ghana",
    "GI": "Gibraltar",
    "GIB": "Gibraltar",
    "GR": "Greece",
    "GRC": "Greece",
    "GL": "Greenland",
    "GRL": "Greenland",
    "GD": "Grenada",
    "GRD": "Grenada",
    "GP": "Guadeloupe",
    "GLP": "Guadeloupe",
    "GU": "Guam",
    "GUM": "Guam",
    "GT": "Guatemala",
    "GTM": "Guatemala",
    "GG": "Guernsey",
    "GGY": "Guernsey",
    "GN": "Guinea",
    "GIN": "Guinea",
    "GW": "Guinea-Bissau",
    "GNB": "Guinea-Bissau",
    "GY": "Guyana",
    "GUY": "Guyana",
    "HT": "Haiti",
    "HTI": "Haiti",
    "HM": "Heard Island and McDonald Islands",
    "HMD": "Heard Island and McDonald Islands",
    "VA": "Holy See",
    "VAT": "Holy See",
    "HN": "Honduras",
    "HND": "Honduras",
    "HK": "Hong Kong",
    "HKG": "Hong Kong",
    "HU": "Hungary",
    "HUN": "Hungary",
    "IS": "Iceland",
    "ISL": "Iceland",
    "IN": "India",
    "IND": "India",
    "ID": "Indonesia",
    "IDN": "Indonesia",
    "IR": "Iran (Islamic Republic of)",
    "IRN": "Iran (Islamic Republic of)",
    "IQ": "Iraq",
    "IRQ": "Iraq",
    "IE": "Ireland",
    "IRL": "Ireland",
    "IM": "Isle of Man",
    "IMN": "Isle of Man",
    "IL": "Israel",
    "ISR": "Israel",
    "IT": "Italy",
    "ITA": "Italy",
    "JM": "Jamaica",
    "JAM": "Jamaica",
    "JP": "Japan",
    "JPN": "Japan",
    "JE": "Jersey",
    "JEY": "Jersey",
    "JO": "Jordan",
    "JOR": "Jordan",
    "KZ": "Kazakhstan",
    "KAZ": "Kazakhstan",
    "KE": "Kenya",
    "KEN": "Kenya",
    "KI": "Kiribati",
    "KIR": "Kiribati",
    "KP": "Korea (Democratic People's Republic of)",
    "PRK": "Korea (Democratic People's Republic of)",
    "KR": "Korea (Republic of)",
    "KOR": "Korea (Republic of)",
    "KW": "Kuwait",
    "KWT": "Kuwait",
    "KG": "Kyrgyzstan",
    "KGZ": "Kyrgyzstan",
    "LA": "Lao People's Democratic Republic",
    "LAO": "Lao People's Democratic Republic",
    "LV": "Latvia",
    "LVA": "Latvia",
    "LB": "Lebanon",
    "LBN": "Lebanon",
    "LS": "Lesotho",
    "LSO": "Lesotho",
    "LR": "Liberia",
    "LBR": "Liberia",
    "LY": "Libya",
    "LBY": "Libya",
    "LI": "Liechtenstein",
    "LIE": "Liechtenstein",
    "LT": "Lithuania",
    "LTU": "Lithuania",
    "LU": "Luxembourg",
    "LUX": "Luxembourg",
    "MO": "Macao",
    "MAC": "Macao",
    "MK": "Macedonia (the former Yugoslav Republic of)",
    "MKD": "Macedonia (the former Yugoslav Republic of)",
    "MG": "Madagascar",
    "MDG": "Madagascar",
    "MW": "Malawi",
    "MWI": "Malawi",
    "MY": "Malaysia",
    "MYS": "Malaysia",
    "MV": "Maldives",
    "MDV": "Maldives",
    "ML": "Mali",
    "MLI": "Mali",
    "MT": "Malta",
    "MLT": "Malta",
    "MH": "Marshall Islands",
    "MHL": "Marshall Islands",
    "MQ": "Martinique",
    "MTQ": "Martinique",
    "MR": "Mauritania",
    "MRT": "Mauritania",
    "MU": "Mauritius",
    "MUS": "Mauritius",
    "YT": "Mayotte",
    "MYT": "Mayotte",
    "MX": "Mexico",
    "MEX": "Mexico",
    "FM": "Micronesia (Federated States of)",
    "FSM": "Micronesia (Federated States of)",
    "MD": "Moldova (Republic of)",
    "MDA": "Moldova (Republic of)",
    "MC": "Monaco",
    "MCO": "Monaco",
    "MN": "Mongolia",
    "MNG": "Mongolia",
    "ME": "Montenegro",
    "MNE": "Montenegro",
    "MS": "Montserrat",
    "MSR": "Montserrat",
    "MA": "Morocco",
    "MAR": "Morocco",
    "MZ": "Mozambique",
    "MOZ": "Mozambique",
    "MM": "Myanmar",
    "MMR": "Myanmar",
    "NA": "Namibia",
    "NAM": "Namibia",
    "NR": "Nauru",
    "NRU": "Nauru",
    "NP": "Nepal",
    "NPL": "Nepal",
    "NL": "Netherlands",
    "NLD": "Netherlands",
    "NC": "New Caledonia",
    "NCL": "New Caledonia",
    "NZ": "New Zealand",
    "NZL": "New Zealand",
    "NI": "Nicaragua",
    "NIC": "Nicaragua",
    "NE": "Niger",
    "NER": "Niger",
    "NG": "Nigeria",
    "NGA": "Nigeria",
    "NU": "Niue",
    "NIU": "Niue",
    "NF": "Norfolk Island",
    "NFK": "Norfolk Island",
    "MP": "Northern Mariana Islands",
    "MNP": "Northern Mariana Islands",
    "NO": "Norway",
    "NOR": "Norway",
    "OM": "Oman",
    "OMN": "Oman",
    "PK": "Pakistan",
    "PAK": "Pakistan",
    "PW": "Palau",
    "PLW": "Palau",
    "PS": "Palestine, State of",
    "PSE": "Palestine, State of",
    "PA": "Panama",
    "PAN": "Panama",
    "PG": "Papua New Guinea",
    "PNG": "Papua New Guinea",
    "PY": "Paraguay",
    "PRY": "Paraguay",
    "PE": "Peru",
    "PER": "Peru",
    "PH": "Philippines",
    "PHL": "Philippines",
    "PN": "Pitcairn",
    "PCN": "Pitcairn",
    "PL": "Poland",
    "POL": "Poland",
    "PT": "Portugal",
    "PRT": "Portugal",
    "PR": "Puerto Rico",
    "PRI": "Puerto Rico",
    "QA": "Qatar",
    "QAT": "Qatar",
    "RE": "Réunion",
    "REU": "Réunion",
    "RO": "Romania",
    "ROU": "Romania",
    "RU": "Russian Federation",
    "RUS": "Russian Federation",
    "RW": "Rwanda",
    "RWA": "Rwanda",
    "BL": "Saint Barthélemy",
    "BLM": "Saint Barthélemy",
    "SH": "Saint Helena, Ascension and Tristan da Cunha",
    "SHN": "Saint Helena, Ascension and Tristan da Cunha",
    "KN": "Saint Kitts and Nevis",
    "KNA": "Saint Kitts and Nevis",
    "LC": "Saint Lucia",
    "LCA": "Saint Lucia",
    "MF": "Saint Martin (French part)",
    "MAF": "Saint Martin (French part)",
    "PM": "Saint Pierre and Miquelon",
    "SPM": "Saint Pierre and Miquelon",
    "VC": "Saint Vincent and the Grenadines",
    "VCT": "Saint Vincent and the Grenadines",
    "WS": "Samoa",
    "WSM": "Samoa",
    "SM": "San Marino",
    "SMR": "San Marino",
    "ST": "Sao Tome and Principe",
    "STP": "Sao Tome and Principe",
    "SA": "Saudi Arabia",
    "SAU": "Saudi Arabia",
    "SN": "Senegal",
    "SEN": "Senegal",
    "RS": "Serbia",
    "SRB": "Serbia",
    "SC": "Seychelles",
    "SYC": "Seychelles",
    "SL": "Sierra Leone",
    "SLE": "Sierra Leone",
    "SG": "Singapore",
    "SGP": "Singapore",
    "SX": "Sint Maarten (Dutch part)",
    "SXM": "Sint Maarten (Dutch part)",
    "SK": "Slovakia",
    "SVK": "Slovakia",
    "SI": "Slovenia",
    "SVN": "Slovenia",
    "SB": "Solomon Islands",
    "SLB": "Solomon Islands",
    "SO": "Somalia",
    "SOM": "Somalia",
    "ZA": "South Africa",
    "ZAF": "South Africa",
    "GS": "South Georgia and the South Sandwich Islands",
    "SGS": "South Georgia and the South Sandwich Islands",
    "SS": "South Sudan",
    "SSD": "South Sudan",
    "ES": "Spain",
    "ESP": "Spain",
    "LK": "Sri Lanka",
    "LKA": "Sri Lanka",
    "SD": "Sudan",
    "SDN": "Sudan",
    "SR": "Suriname",
    "SUR": "Suriname",
    "SJ": "Svalbard and Jan Mayen",
    "SJM": "Svalbard and Jan Mayen",
    "SZ": "Swaziland",
    "SWZ": "Swaziland",
    "SE": "Sweden",
    "SWE": "Sweden",
    "CH": "Switzerland",
    "CHE": "Switzerland",
    "SY": "Syrian Arab Republic",
    "SYR": "Syrian Arab Republic",
    "TW": "Taiwan, Province of China[note 1]",
    "TWN": "Taiwan, Province of China[note 1]",
    "TJ": "Tajikistan",
    "TJK": "Tajikistan",
    "TZ": "Tanzania, United Republic of",
    "TZA": "Tanzania, United Republic of",
    "TH": "Thailand",
    "THA": "Thailand",
    "TL": "Timor-Leste",
    "TLS": "Timor-Leste",
    "TG": "Togo",
    "TGO": "Togo",
    "TK": "Tokelau",
    "TKL": "Tokelau",
    "TO": "Tonga",
    "TON": "Tonga",
    "TT": "Trinidad and Tobago",
    "TTO": "Trinidad and Tobago",
    "TN": "Tunisia",
    "TUN": "Tunisia",
    "TR": "Turkey",
    "TUR": "Turkey",
    "TM": "Turkmenistan",
    "TKM": "Turkmenistan",
    "TC": "Turks and Caicos Islands",
    "TCA": "Turks and Caicos Islands",
    "TV": "Tuvalu",
    "TUV": "Tuvalu",
    "UG": "Uganda",
    "UGA": "Uganda",
    "UA": "Ukraine",
    "UKR": "Ukraine",
    "AE": "United Arab Emirates",
    "ARE": "United Arab Emirates",
    "GB": "United Kingdom of Great Britain and Northern Ireland",
    "GBR": "United Kingdom of Great Britain and Northern Ireland",
    "US": "United States of America",
    "USA": "United States of America",
    "UM": "United States Minor Outlying Islands",
    "UMI": "United States Minor Outlying Islands",
    "UY": "Uruguay",
    "URY": "Uruguay",
    "UZ": "Uzbekistan",
    "UZB": "Uzbekistan",
    "VU": "Vanuatu",
    "VUT": "Vanuatu",
    "VE": "Venezuela (Bolivarian Republic of)",
    "VEN": "Venezuela (Bolivarian Republic of)",
    "VN": "Viet Nam",
    "VNM": "Viet Nam",
    "VG": "Virgin Islands (British)",
    "VGB": "Virgin Islands (British)",
    "VI": "Virgin Islands (U.S.)",
    "VIR": "Virgin Islands (U.S.)",
    "WF": "Wallis and Futuna",
    "WLF": "Wallis and Futuna",
    "EH": "Western Sahara",
    "ESH": "Western Sahara",
    "YE": "Yemen",
    "YEM": "Yemen",
    "ZM": "Zambia",
    "ZMB": "Zambia",
    "ZW": "Zimbabwe",
    "ZWE": "Zimbabwe"
}

country_name_map = {
    "AF": "阿富汗",
    "AFG": "阿富汗",
    "AX": "奥兰",
    "ALA": "奥兰",
    "AL": "阿尔巴尼亚",
    "ALB": "阿尔巴尼亚",
    "DZ": "阿尔及利亚",
    "DZA": "阿尔及利亚",
    "AS": "美属萨摩亚",
    "ASM": "美属萨摩亚",
    "AD": "安道尔",
    "AND": "安道尔",
    "AO": "安哥拉",
    "AGO": "安哥拉",
    "AI": "安圭拉",
    "AIA": "安圭拉",
    "AQ": "南极洲",
    "ATA": "南极洲",
    "AG": "安提瓜和巴布达",
    "ATG": "安提瓜和巴布达",
    "AR": "阿根廷",
    "ARG": "阿根廷",
    "AM": "亚美尼亚",
    "ARM": "亚美尼亚",
    "AW": "阿鲁巴",
    "ABW": "阿鲁巴",
    "AU": "澳大利亚",
    "AUS": "澳大利亚",
    "AT": "奥地利",
    "AUT": "奥地利",
    "AZ": "阿塞拜疆",
    "AZE": "阿塞拜疆",
    "BS": "巴哈马",
    "BHS": "巴哈马",
    "BH": "巴林",
    "BHR": "巴林",
    "BD": "孟加拉国",
    "BGD": "孟加拉国",
    "BB": "巴巴多斯",
    "BRB": "巴巴多斯",
    "BY": "白俄罗斯",
    "BLR": "白俄罗斯",
    "BE": "比利时",
    "BEL": "比利时",
    "BZ": "伯利兹",
    "BLZ": "伯利兹",
    "BJ": "贝宁",
    "BEN": "贝宁",
    "BM": "百慕大",
    "BMU": "百慕大",
    "BT": "不丹",
    "BTN": "不丹",
    "BO": "玻利维亚",
    "BOL": "玻利维亚",
    "BQ": "荷兰加勒比区",
    "BES": "荷兰加勒比区",
    "BA": "波斯尼亚和黑塞哥维那",
    "BIH": "波斯尼亚和黑塞哥维那",
    "BW": "博茨瓦纳",
    "BWA": "博茨瓦纳",
    "BV": "布韦岛",
    "BVT": "布韦岛",
    "BR": "巴西",
    "BRA": "巴西",
    "IO": "英属印度洋领地",
    "IOT": "英属印度洋领地",
    "BN": "文莱",
    "BRN": "文莱",
    "BG": "保加利亚",
    "BGR": "保加利亚",
    "BF": "布基纳法索",
    "BFA": "布基纳法索",
    "BI": "布隆迪",
    "BDI": "布隆迪",
    "CV": "佛得角",
    "CPV": "佛得角",
    "KH": "柬埔寨",
    "KHM": "柬埔寨",
    "CM": "喀麦隆",
    "CMR": "喀麦隆",
    "CA": "加拿大",
    "CAN": "加拿大",
    "KY": "开曼群岛",
    "CYM": "开曼群岛",
    "CF": "中非",
    "CAF": "中非",
    "TD": "乍得",
    "TCD": "乍得",
    "CL": "智利",
    "CHL": "智利",
    "CN": "中国",
    "CHN": "中国",
    "CX": "圣诞岛",
    "CXR": "圣诞岛",
    "CC": "科科斯（基林）群岛",
    "CCK": "科科斯（基林）群岛",
    "CO": "哥伦比亚",
    "COL": "哥伦比亚",
    "KM": "科摩罗",
    "COM": "科摩罗",
    "CG": "刚果（布）",
    "COG": "刚果（布）",
    "CD": "刚果（金）",
    "COD": "刚果（金）",
    "CK": "库克群岛",
    "COK": "库克群岛",
    "CR": "哥斯达黎加",
    "CRI": "哥斯达黎加",
    "CI": "科特迪瓦",
    "CIV": "科特迪瓦",
    "HR": "克罗地亚",
    "HRV": "克罗地亚",
    "CU": "古巴",
    "CUB": "古巴",
    "CW": "库拉索",
    "CUW": "库拉索",
    "CY": "塞浦路斯",
    "CYP": "塞浦路斯",
    "CZ": "捷克",
    "CZE": "捷克",
    "DK": "丹麦",
    "DNK": "丹麦",
    "DJ": "吉布提",
    "DJI": "吉布提",
    "DM": "多米尼克",
    "DMA": "多米尼克",
    "DO": "多米尼加",
    "DOM": "多米尼加",
    "EC": "厄瓜多尔",
    "ECU": "厄瓜多尔",
    "EG": "埃及",
    "EGY": "埃及",
    "SV": "萨尔瓦多",
    "SLV": "萨尔瓦多",
    "GQ": "赤道几内亚",
    "GNQ": "赤道几内亚",
    "ER": "厄立特里亚",
    "ERI": "厄立特里亚",
    "EE": "爱沙尼亚",
    "EST": "爱沙尼亚",
    "ET": "埃塞俄比亚",
    "ETH": "埃塞俄比亚",
    "FK": "福克兰群岛",
    "FLK": "福克兰群岛",
    "FO": "法罗群岛",
    "FRO": "法罗群岛",
    "FJ": "斐济",
    "FJI": "斐济",
    "FI": "芬兰",
    "FIN": "芬兰",
    "FR": "法国",
    "FRA": "法国",
    "GF": "法属圭亚那",
    "GUF": "法属圭亚那",
    "PF": "法属波利尼西亚",
    "PYF": "法属波利尼西亚",
    "TF": "法属南方和南极洲领地",
    "ATF": "法属南方和南极洲领地",
    "GA": "加蓬",
    "GAB": "加蓬",
    "GM": "冈比亚",
    "GMB": "冈比亚",
    "GE": "格鲁吉亚",
    "GEO": "格鲁吉亚",
    "DE": "德国",
    "DEU": "德国",
    "GH": "加纳",
    "GHA": "加纳",
    "GI": "直布罗陀",
    "GIB": "直布罗陀",
    "GR": "希腊",
    "GRC": "希腊",
    "GL": "格陵兰",
    "GRL": "格陵兰",
    "GD": "格林纳达",
    "GRD": "格林纳达",
    "GP": "瓜德罗普",
    "GLP": "瓜德罗普",
    "GU": "关岛",
    "GUM": "关岛",
    "GT": "危地马拉",
    "GTM": "危地马拉",
    "GG": "根西",
    "GGY": "根西",
    "GN": "几内亚",
    "GIN": "几内亚",
    "GW": "几内亚比绍",
    "GNB": "几内亚比绍",
    "GY": "圭亚那",
    "GUY": "圭亚那",
    "HT": "海地",
    "HTI": "海地",
    "HM": "赫德岛和麦克唐纳群岛",
    "HMD": "赫德岛和麦克唐纳群岛",
    "VA": "梵蒂冈",
    "VAT": "梵蒂冈",
    "HN": "洪都拉斯",
    "HND": "洪都拉斯",
    "HK": "香港",
    "HKG": "香港",
    "HU": "匈牙利",
    "HUN": "匈牙利",
    "IS": "冰岛",
    "ISL": "冰岛",
    "IN": "印度",
    "IND": "印度",
    "ID": "印尼",
    "IDN": "印尼",
    "IR": "伊朗",
    "IRN": "伊朗",
    "IQ": "伊拉克",
    "IRQ": "伊拉克",
    "IE": "爱尔兰",
    "IRL": "爱尔兰",
    "IM": "马恩岛",
    "IMN": "马恩岛",
    "IL": "以色列",
    "ISR": "以色列",
    "IT": "意大利",
    "ITA": "意大利",
    "JM": "牙买加",
    "JAM": "牙买加",
    "JP": "日本",
    "JPN": "日本",
    "JE": "泽西",
    "JEY": "泽西",
    "JO": "约旦",
    "JOR": "约旦",
    "KZ": "哈萨克斯坦",
    "KAZ": "哈萨克斯坦",
    "KE": "肯尼亚",
    "KEN": "肯尼亚",
    "KI": "基里巴斯",
    "KIR": "基里巴斯",
    "KP": "朝鲜",
    "PRK": "朝鲜",
    "KR": "韩国",
    "KOR": "韩国",
    "KW": "科威特",
    "KWT": "科威特",
    "KG": "吉尔吉斯斯坦",
    "KGZ": "吉尔吉斯斯坦",
    "LA": "老挝",
    "LAO": "老挝",
    "LV": "拉脱维亚",
    "LVA": "拉脱维亚",
    "LB": "黎巴嫩",
    "LBN": "黎巴嫩",
    "LS": "莱索托",
    "LSO": "莱索托",
    "LR": "利比里亚",
    "LBR": "利比里亚",
    "LY": "利比亚",
    "LBY": "利比亚",
    "LI": "列支敦士登",
    "LIE": "列支敦士登",
    "LT": "立陶宛",
    "LTU": "立陶宛",
    "LU": "卢森堡",
    "LUX": "卢森堡",
    "MO": "澳门",
    "MAC": "澳门",
    "MK": "马其顿",
    "MKD": "马其顿",
    "MG": "马达加斯加",
    "MDG": "马达加斯加",
    "MW": "马拉维",
    "MWI": "马拉维",
    "MY": "马来西亚",
    "MYS": "马来西亚",
    "MV": "马尔代夫",
    "MDV": "马尔代夫",
    "ML": "马里",
    "MLI": "马里",
    "MT": "马耳他",
    "MLT": "马耳他",
    "MH": "马绍尔群岛",
    "MHL": "马绍尔群岛",
    "MQ": "马提尼克",
    "MTQ": "马提尼克",
    "MR": "毛里塔尼亚",
    "MRT": "毛里塔尼亚",
    "MU": "毛里求斯",
    "MUS": "毛里求斯",
    "YT": "马约特",
    "MYT": "马约特",
    "MX": "墨西哥",
    "MEX": "墨西哥",
    "FM": "密克罗尼西亚联邦",
    "FSM": "密克罗尼西亚联邦",
    "MD": "摩尔多瓦",
    "MDA": "摩尔多瓦",
    "MC": "摩纳哥",
    "MCO": "摩纳哥",
    "MN": "蒙古国",
    "MNG": "蒙古国",
    "ME": "黑山",
    "MNE": "黑山",
    "MS": "蒙特塞拉特",
    "MSR": "蒙特塞拉特",
    "MA": "摩洛哥",
    "MAR": "摩洛哥",
    "MZ": "莫桑比克",
    "MOZ": "莫桑比克",
    "MM": "缅甸",
    "MMR": "缅甸",
    "NA": "纳米比亚",
    "NAM": "纳米比亚",
    "NR": "瑙鲁",
    "NRU": "瑙鲁",
    "NP": "尼泊尔",
    "NPL": "尼泊尔",
    "NL": "荷兰",
    "NLD": "荷兰",
    "NC": "新喀里多尼亚",
    "NCL": "新喀里多尼亚",
    "NZ": "新西兰",
    "NZL": "新西兰",
    "NI": "尼加拉瓜",
    "NIC": "尼加拉瓜",
    "NE": "尼日尔",
    "NER": "尼日尔",
    "NG": "尼日利亚",
    "NGA": "尼日利亚",
    "NU": "纽埃",
    "NIU": "纽埃",
    "NF": "诺福克岛",
    "NFK": "诺福克岛",
    "MP": "北马里亚纳群岛",
    "MNP": "北马里亚纳群岛",
    "NO": "挪威",
    "NOR": "挪威",
    "OM": "阿曼",
    "OMN": "阿曼",
    "PK": "巴基斯坦",
    "PAK": "巴基斯坦",
    "PW": "帕劳",
    "PLW": "帕劳",
    "PS": "巴勒斯坦",
    "PSE": "巴勒斯坦",
    "PA": "巴拿马",
    "PAN": "巴拿马",
    "PG": "巴布亚新几内亚",
    "PNG": "巴布亚新几内亚",
    "PY": "巴拉圭",
    "PRY": "巴拉圭",
    "PE": "秘鲁",
    "PER": "秘鲁",
    "PH": "菲律宾",
    "PHL": "菲律宾",
    "PN": "皮特凯恩群岛",
    "PCN": "皮特凯恩群岛",
    "PL": "波兰",
    "POL": "波兰",
    "PT": "葡萄牙",
    "PRT": "葡萄牙",
    "PR": "波多黎各",
    "PRI": "波多黎各",
    "QA": "卡塔尔",
    "QAT": "卡塔尔",
    "RE": "留尼汪",
    "REU": "留尼汪",
    "RO": "罗马尼亚",
    "ROU": "罗马尼亚",
    "RU": "俄罗斯",
    "RUS": "俄罗斯",
    "RW": "卢旺达",
    "RWA": "卢旺达",
    "BL": "圣巴泰勒米",
    "BLM": "圣巴泰勒米",
    "SH": "圣赫勒拿、阿森松和特里斯坦-达库尼亚",
    "SHN": "圣赫勒拿、阿森松和特里斯坦-达库尼亚",
    "KN": "圣基茨和尼维斯",
    "KNA": "圣基茨和尼维斯",
    "LC": "圣卢西亚",
    "LCA": "圣卢西亚",
    "MF": "法属圣马丁",
    "MAF": "法属圣马丁",
    "PM": "圣皮埃尔和密克隆",
    "SPM": "圣皮埃尔和密克隆",
    "VC": "圣文森特和格林纳丁斯",
    "VCT": "圣文森特和格林纳丁斯",
    "WS": "萨摩亚",
    "WSM": "萨摩亚",
    "SM": "圣马力诺",
    "SMR": "圣马力诺",
    "ST": "圣多美和普林西比",
    "STP": "圣多美和普林西比",
    "SA": "沙特阿拉伯",
    "SAU": "沙特阿拉伯",
    "SN": "塞内加尔",
    "SEN": "塞内加尔",
    "RS": "塞尔维亚",
    "SRB": "塞尔维亚",
    "SC": "塞舌尔",
    "SYC": "塞舌尔",
    "SL": "塞拉利昂",
    "SLE": "塞拉利昂",
    "SG": "新加坡",
    "SGP": "新加坡",
    "SX": "圣马丁",
    "SXM": "圣马丁",
    "SK": "斯洛伐克",
    "SVK": "斯洛伐克",
    "SI": "斯洛文尼亚",
    "SVN": "斯洛文尼亚",
    "SB": "所罗门群岛",
    "SLB": "所罗门群岛",
    "SO": "索马里",
    "SOM": "索马里",
    "ZA": "南非",
    "ZAF": "南非",
    "GS": "南乔治亚和南桑威奇群岛",
    "SGS": "南乔治亚和南桑威奇群岛",
    "SS": "南苏丹",
    "SSD": "南苏丹",
    "ES": "西班牙",
    "ESP": "西班牙",
    "LK": "斯里兰卡",
    "LKA": "斯里兰卡",
    "SD": "苏丹",
    "SDN": "苏丹",
    "SR": "苏里南",
    "SUR": "苏里南",
    "SJ": "斯瓦尔巴和扬马延",
    "SJM": "斯瓦尔巴和扬马延",
    "SZ": "斯威士兰",
    "SWZ": "斯威士兰",
    "SE": "瑞典",
    "SWE": "瑞典",
    "CH": "瑞士",
    "CHE": "瑞士",
    "SY": "叙利亚",
    "SYR": "叙利亚",
    "TW": "中国台湾省",
    "TWN": "中国台湾省",
    "TJ": "塔吉克斯坦",
    "TJK": "塔吉克斯坦",
    "TZ": "坦桑尼亚",
    "TZA": "坦桑尼亚",
    "TH": "泰国",
    "THA": "泰国",
    "TL": "东帝汶",
    "TLS": "东帝汶",
    "TG": "多哥",
    "TGO": "多哥",
    "TK": "托克劳",
    "TKL": "托克劳",
    "TO": "汤加",
    "TON": "汤加",
    "TT": "特立尼达和多巴哥",
    "TTO": "特立尼达和多巴哥",
    "TN": "突尼斯",
    "TUN": "突尼斯",
    "TR": "土耳其",
    "TUR": "土耳其",
    "TM": "土库曼斯坦",
    "TKM": "土库曼斯坦",
    "TC": "特克斯和凯科斯群岛",
    "TCA": "特克斯和凯科斯群岛",
    "TV": "图瓦卢",
    "TUV": "图瓦卢",
    "UG": "乌干达",
    "UGA": "乌干达",
    "UA": "乌克兰",
    "UKR": "乌克兰",
    "AE": "阿联酋",
    "ARE": "阿联酋",
    "GB": "英国",
    "GBR": "英国",
    "US": "美国",
    "USA": "美国",
    "UM": "美国本土外小岛屿",
    "UMI": "美国本土外小岛屿",
    "UY": "乌拉圭",
    "URY": "乌拉圭",
    "UZ": "乌兹别克斯坦",
    "UZB": "乌兹别克斯坦",
    "VU": "瓦努阿图",
    "VUT": "瓦努阿图",
    "VE": "委内瑞拉",
    "VEN": "委内瑞拉",
    "VN": "越南",
    "VNM": "越南",
    "VG": "英属维尔京群岛",
    "VGB": "英属维尔京群岛",
    "VI": "美属维尔京群岛",
    "VIR": "美属维尔京群岛",
    "WF": "瓦利斯和富图纳",
    "WLF": "瓦利斯和富图纳",
    "EH": "西撒哈拉",
    "ESH": "西撒哈拉",
    "YE": "也门",
    "YEM": "也门",
    "ZM": "赞比亚",
    "ZMB": "赞比亚",
    "ZW": "津巴布韦",
    "ZWE": "津巴布韦",
}